#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_FAST_HYPOT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_FAST_HYPOT_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/scalar/fast_hypot.hpp>

#endif
